%global commit 9a8ab938b4024af8f0455edb54f80fdb5195968b
%global date   20141101
# this is a pre-release of upstream
%global pre    pre

# python3 for Fedora only (not available at EPEL)
%if 0%{?fedora}
%global with_python3 1
%endif

Name:           py4j
Version:        0.9
Release:        0.1.%{pre}.%{date}git%(c=%{commit}; echo ${c:0:7})%{?dist}
Summary:        Py4J enables Python programs to dynamically access arbitrary Java objects

License:        BSD
URL:            https://%{name}.sf.net
Source0:        https://github.com/bartdag/%{name}/archive/%{commit}/%{commit}.tar.gz#/%{name}-%{commit}.tar.gz
# F22+ unbundles hamcrest from junit.jar
Patch0:         py4j-0.8.3-add-hamcrest-in-classpath.patch

BuildArch:      noarch

BuildRequires:  python2-devel python-setuptools

%if 0%{?with_python3}
BuildRequires:  python3-devel python3-setuptools
%endif

# generate additional documentation with sphinx
Requires:       python-sphinx

BuildRequires:  ant-junit maven-local
BuildRequires:  sonatype-oss-parent

# F22+ unbundles hamcrest from junit
%if 0%{?fedora} >= 22
BuildRequires:  hamcrest
%endif

BuildRequires:  python-sphinx
BuildRequires:  python-nose

Requires:       %{name}-java = %{version}-%{release}

%description
Py4J enables Python programs running in a Python interpreter
to dynamically access Java objects in a Java Virtual Machine.
Methods are called as if the Java objects resided in the Python
interpreter and Java collections can be accessed through standard
Python collection methods.
Py4J also enables Java programs to call back Python objects.
Py4J is distributed under the BSD license.


%if 0%{?with_python3} 
%package -n python3-%{name}
Summary:        Py4J enables Python3 programs to dynamically access arbitrary Java objects
Requires:       python3
Requires:       %{name}-java = %{version}-%{release}
%endif

%if 0%{?with_python3}
%description -n python3-%{name}
Py4J enables Python3 programs running in a Python interpreter
to dynamically access Java objects in a Java Virtual Machine.
Methods are called as if the Java objects resided in the Python
interpreter and Java collections can be accessed through standard
Python collection methods.
Py4J also enables Java programs to call back Python objects.
Py4J is distributed under the BSD license.
This package is for usage with Python3 only.
%endif


%package java
Summary:        Py4J Java Library

%description java
%{summary}.


%package javadoc
Summary:        Javadoc files for %{name}

%description javadoc
%{summary}.


%package doc
Summary:        Documentation files for %{name}

%description doc
%{summary}.


%prep
%setup -qn%{name}-%{commit}
%if 0%{?fedora} >= 22
%patch0 -p0
%endif
# remove unneeded stuff
rm -r current-release net.sf.* .*.yml setup.py
find . -name \*.jar -print -delete
# build jar without version in name
sed -i "s|version=.*|version=|" %{name}-java/ant.properties
sed -i "s|'.*'|''|" %{name}-python/src/%{name}/version.py

pushd %{name}-java
# set classpath to unbundle junit (and hamcrest)
sed -i "s|junit-.*\.jar|$(build-classpath junit)|g" ant.properties
# set default java version to avoid some warnings
%if 0%{?fedora} >= 21
sed -i "s|1\.6|1.8|g" build.xml
%endif
popd

# do not build tests by default (later done in check) and install jar manually (with maven)
pushd %{name}-python
sed -i -e "s|%{name}\.tests||" -e "/data_files/d" setup.py
rm src/dummy_test.py
popd

# build separately for python3 in special subfolder
%if 0%{?with_python3}
cp -a %{name}-python python3
%endif


%build
pushd %{name}-java
ant jar javadoc
popd

pushd %{name}-python
%{__python2} setup.py build
popd

%if 0%{?with_python3}
pushd python3
%{__python3} setup.py build
popd
%endif

make -C %{name}-web html


%install
pushd %{name}-python
%{__python2} setup.py install -O1 --skip-build --root %{buildroot}
popd

%if 0%{?with_python3}
pushd python3
%{__python3} setup.py install -O1 --skip-build --root %{buildroot}
popd
%endif

%mvn_artifact %{name}-java/pom.xml %{name}-java/*.jar
%mvn_install -J %{name}-java/javadoc
mkdir -p %{buildroot}%{_datadir}/%{name}
ln -sf %{javadir}/%{name}/*.jar %{buildroot}%{_datadir}/%{name}


%check
# do build tests only, see above
sed -e "s|src|%{name}-python/\0|g" -e "s|'%{name}', ||" %{name}-python/setup.py >setup.py
ant -f %{name}-java/build.xml python-test java-test
# FIXME run tests also for py3?


%files
%license %{name}-python/LICENSE.txt
%doc README.rst %{name}-python/README.txt
%{python2_sitelib}/*.egg-info
%{python2_sitelib}/%{name}/

%if 0%{?with_python3}
%files -n python3-%{name}
%license %{name}-python/LICENSE.txt
%doc README.rst %{name}-python/README.txt
%{python3_sitelib}/*.egg-info
%{python3_sitelib}/%{name}/
%endif

%files java -f .mfiles
%license %{name}-java/LICENSE.txt
%doc %{name}-java/README.txt %{name}-java/changelog.txt
%dir %{_datadir}/%{name}
%{_datadir}/%{name}/*.jar

%files doc
%license %{name}-web/LICENSE
%doc %{name}-web/TODO %{name}-python/release_process.txt
%doc %{name}-web/*.rst %{name}-web/themes/ %{name}-web/images/
%doc %{name}-web/_build/html/ %{name}-web/Makefile

%files javadoc -f .mfiles-javadoc
%license %{name}-java/LICENSE.txt


%changelog
* Mon Apr 27 2015 Raphael Groner <projects.rg@smart.ms> - 0.9-0.1.pre.20141101git9a8ab93
- initial
